==> reference3-1.0-sources.jar: one/xingyi/reference3/address/client/view/AddressLine12View.java <==
package one.xingyi.reference3.address.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.reference3.address.IAddressLine12ViewDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import java.lang.String;
public interface AddressLine12View  extends IXingYiView<one.xingyi.reference3.address.client.entitydefn.IAddressClientEntity>{
    //ViewFieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=line1, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('line1');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=line1, readOnly=false, lensName=lens_Address_line1, lensPath=line1/String, javascript=function lens_Address_line1(){return lens('line1');};, templated=false, deprecated=false)]
    default public Lens<AddressLine12View,java.lang.String> line1Lens(){ return xingYi().stringLens(one.xingyi.reference3.address.client.viewcompanion.AddressLine12ViewCompanion.companion, "lens_Address_line1");}
    default public java.lang.String line1(){ return line1Lens().get(this);};
    default public AddressLine12View withline1(java.lang.String line1){ return line1Lens().set(this,line1);}
    //ViewFieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=line2, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('line2');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=PrimitiveType(typeName=PackageAndClassName(packageName=java.lang, className=String)), name=line2, readOnly=false, lensName=lens_Address_line2, lensPath=line2/String, javascript=function lens_Address_line2(){return lens('line2');};, templated=false, deprecated=false)]
    default public Lens<AddressLine12View,java.lang.String> line2Lens(){ return xingYi().stringLens(one.xingyi.reference3.address.client.viewcompanion.AddressLine12ViewCompanion.companion, "lens_Address_line2");}
    default public java.lang.String line2(){ return line2Lens().get(this);};
    default public AddressLine12View withline2(java.lang.String line2){ return line2Lens().set(this,line2);}
}

==> reference3-1.1-sources.jar: one/xingyi/reference3/address/client/view/AddressLine12View.java <==
package one.xingyi.reference3.address.client.view;
//Made by one.xingyi.core.filemaker.ClientViewInterfaceFileMaker
//Defn one.xingyi.reference3.address.IAddressLine12ViewDefn
import one.xingyi.core.sdk.IXingYiView;
import one.xingyi.core.annotations.XingYiGenerated;
import java.util.function.Function;
import one.xingyi.core.http.ServiceRequest;
import one.xingyi.core.http.ServiceResponse;
import one.xingyi.core.utils.IdAndValue;
import java.util.Optional;
import one.xingyi.core.optics.Lens;
import java.util.concurrent.CompletableFuture;
import one.xingyi.core.httpClient.HttpServiceCompletableFuture;
import one.xingyi.core.httpClient.client.view.UrlPattern;
import java.lang.String;
public interface AddressLine12View  extends IXingYiView<one.xingyi.reference3.address.client.entitydefn.IAddressClientEntity>{
    //ViewFieldDom(typeDom=StringPrimitiveType(), name=line1, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('line1');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=StringPrimitiveType(), name=line1, readOnly=false, lensName=lens_Address_line1, lensPath=line1/String, javascript=function lens_Address_line1(){return lens('line1');};, templated=false, deprecated=false)]
    default public Lens<AddressLine12View,java.lang.String> line1Lens(){ return xingYi().stringLens(one.xingyi.reference3.address.client.viewcompanion.AddressLine12ViewCompanion.companion, "lens_Address_line1");}
    default public java.lang.String line1(){ return line1Lens().get(this);};
    default public AddressLine12View withline1(java.lang.String line1){ return line1Lens().set(this,line1);}
    //ViewFieldDom(typeDom=StringPrimitiveType(), name=line2, readOnly=false, lensName=lens for views not done yet, lensPath=lens path for views not done yet, javascript=function lens for views not done yet(){return lens('line2');};, templated=false, deprecated=false)
    //EntityOptional[FieldDom(typeDom=StringPrimitiveType(), name=line2, readOnly=false, lensName=lens_Address_line2, lensPath=line2/String, javascript=function lens_Address_line2(){return lens('line2');};, templated=false, deprecated=false)]
    default public Lens<AddressLine12View,java.lang.String> line2Lens(){ return xingYi().stringLens(one.xingyi.reference3.address.client.viewcompanion.AddressLine12ViewCompanion.companion, "lens_Address_line2");}
    default public java.lang.String line2(){ return line2Lens().get(this);};
    default public AddressLine12View withline2(java.lang.String line2){ return line2Lens().set(this,line2);}
}
